@@ -12,8 +12,29 @@
 #' @param ... further arguments passed to other methods
 #' @return a document object
 #' @export
-#' @seealso \code{\link{docx}}, \code{\link{pptx}}, \code{\link{bsdoc}},
-#' \code{\link{pot}}, \code{\link{textProperties}}, \code{\link{parProperties}}
+#' @examples
+#' # define some text
+#' sometext <- c( "Lorem ipsum dolor sit amet, consectetur adipiscing elit.",
+#'   "In sit amet ipsum tellus. Vivamus dignissim arcu sit amet faucibus auctor.",
+#'   "Quisque dictum tristique ligula.")
+#'
+#' # "My tailor is rich" with formatting on some words
+#' pot1 <- pot("My tailor", textProperties(color = "red" ) ) +
+#'   " is " + pot("rich", textProperties(shading.color = "red",
+#'      font.weight = "bold" ) )
+#'
+#' # "Cats and dogs" with formatting on some words
+#' pot2 = pot("Cats", textProperties(color = "red" ) ) +
+#'   " and " +
+#'   pot("dogs", textProperties( color = "blue" ),
+#'       hyperlink = "http://www.wikipedia.org/" )
+#'
+#' # create a set of paragraphs made of pot1 and pot2
+#' my.pars <- set_of_paragraphs( pot1, pot2 )
+#'
+#' @seealso \code{\link{docx}}, \code{\link{pptx}},
+#' \code{\link{pot}}, \code{\link{textProperties}},
+#' \code{\link{parProperties}}, \code{\link{list.settings}}
 addParagraph <- function(doc, value, ...){
   checkHasSlide(doc)
   if( !inherits( value, c("set_of_paragraphs", "character", "pot") ) )
@@ -31,42 +52,57 @@ addParagraph <- function(doc, value, ...){
 #' Expected value is an existing stylename of the template document used to create the
 #' \code{docx} object. see \code{\link{styles.docx}}.
 #' @param bookmark a character value ; id of the Word bookmark to
-#' replace by the table. optional. See \code{\link{bookmark}}.
-#' @param par.properties \code{\link{parProperties}} to apply to paragraphs, only used
-#' if \code{stylename} if missing.
+#' replace by the table. optional.
+#' @param par.properties \code{\link{parProperties}} to apply to paragraphs. When used in Word
+#' documents, it will only be used if \code{stylename} if missing. When used in PowerPoint
+#' documents, it will be used if \code{offx} or \code{offy} is used.
 #' @param restart.numbering boolean value. If \code{TRUE}, next numbered
 #' list counter will be set to 1.
 #' @examples
-#'
 #' # docx example ---------
+#' \donttest{
 #' doc.filename = "ex_paragraph.docx"
 #' doc <- docx()
 #' styles(doc)
-#' @example examples/addTitle1Level1.R
-#' @example examples/addParagraph_hello_docx.R
-#' @example examples/addTitle2Level1.R
-#' @example examples/addParagraph_bullets_docx.R
-#' @example examples/addTitle3Level1.R
-#' @example examples/pot1_example.R
-#' @example examples/pot2_example.R
-#' @example examples/set_of_paragraphs_example.R
-#' @example examples/addParagraph_sop_docx.R
-#' @example examples/addTitle4Level1.R
-#' @example examples/lists_doc.R
-#' @example examples/writeDoc_file.R
+#'
+#' doc <- addTitle( doc, "Title example 1", level = 1 )
+#' # Add "Hello World" into the document doc
+#' doc <- addParagraph(doc, "Hello Word", stylename = "Normal" )
+#'
+#' doc <- addTitle( doc, "Title example 2", level = 1 )
+#'
+#' # add sometext with stylename BulletList
+#' doc <- addParagraph( doc, value = sometext, stylename="BulletList" )
+#'
+#' doc <- addTitle( doc, "Title example 3", level = 1 )
+#'
+#' doc <- addParagraph( doc, value = my.pars, par.properties = parCenter() )
+#'
+#' writeDoc( doc, file = doc.filename )
+#' }
 #' @rdname addParagraph
 #' @export
 addParagraph.docx <- function(doc, value, stylename, bookmark,
 		par.properties = parProperties(),
 		restart.numbering = FALSE, ... ) {
 
-	if( !missing(stylename) && !is.element( stylename , styles( doc ) ) ){
-		stop(paste("Style {", stylename, "} does not exists.", sep = "") )
+  if( missing( value ) ){
+    stop("argument value is missing." )
+  }
+
+	if( !missing(stylename) && inherits(value, "character") ){
+	  if(!is.element( stylename , styles( doc ) ))
+		  stop(paste("Style {", stylename, "} does not exists.", sep = ""), call. = FALSE )
+
+	  if( missing( bookmark ) ){
+	    .jcall( doc$obj, "V", "addWithStyle" , .jarray(value), stylename)
+	  } else{
+	    .jcall( doc$obj, "V", "addWithStyle", .jarray(value), stylename, bookmark )
+	  }
+    return(doc)
 	}
 
-	if( missing( value ) ){
-		stop("argument value is missing." )
-	} else if( inherits( value, "character" ) ){
+	if( inherits( value, "character" ) ){
 		value = gsub("\\r", "", value )
 		x = lapply( value, function(x) pot(value = x) )
 		value = do.call( "set_of_paragraphs", x )
@@ -89,13 +125,9 @@ addParagraph.docx <- function(doc, value, stylename, bookmark,
 	}
 	.jcall( parset, "V", "setDOCXReference", doc$obj )
 
-	if( missing( bookmark ) && !missing( stylename ) ){
-		.jcall( doc$obj, "V", "addWithStyle" , parset, stylename)
-	} else if( missing( bookmark ) && missing( stylename ) ){
+	if( missing( bookmark ) ){
 		.jcall( doc$obj, "V", "add" , parset )
-	} else if( !missing( bookmark ) && !missing( stylename ) ){
-		.jcall( doc$obj, "V", "addWithStyle", parset, stylename, bookmark )
-	} else if( !missing( bookmark ) && missing( stylename ) ){
+	} else {
 		.jcall( doc$obj, "V", "add" , parset, bookmark )
 	}
 
@@ -104,48 +136,6 @@ addParagraph.docx <- function(doc, value, stylename, bookmark,
 
 
 
-
-
-
-
-#' @rdname addParagraph
-#' @export
-addParagraph.bsdoc <- function(doc, value,
-                              par.properties = parProperties(),
-                              restart.numbering = FALSE, ... ) {
-
-  if( inherits( value, "character" ) ){
-    x = lapply( value, function(x) pot(value = x) )
-    value = do.call( "set_of_paragraphs", x )
-  }
-  if( inherits( value, "pot" ) ){
-    value = set_of_paragraphs( value )
-  }
-
-  if( !inherits(value, "set_of_paragraphs") )
-    stop("value must be an object of class pot, set_of_paragraphs or a character vector.")
-
-  parset = .jset_of_paragraphs(value, par.properties)
-
-  if( !inherits( par.properties, "parProperties" ) ){
-    stop("argument 'par.properties' must be an object of class 'parProperties'")
-  }
-
-  if( restart.numbering ){
-    .jcall( doc$jobj, "V", "restartNumbering" )
-  }
-
-  out = .jcall( doc$jobj, "I", "add" , parset )
-  if( out != 1 ){
-    stop( "Problem while trying to add paragrahs." )
-  }
-  doc
-}
-
-
-
-
-
 #' @param offx optional, x position of the shape (top left position of the bounding box)
 #' in inches. See details.
 #' @param offy optional, y position of the shape (top left position of the bounding box)
@@ -171,31 +161,32 @@ addParagraph.bsdoc <- function(doc, value,
 #' Also, when document is a \code{pptx} object,
 #' shading and border settings of argument \code{par.properties}
 #' will have no effect.
-#' @examples
 #'
+#' If character values are used to fill slides, parameter \code{append}
+#' will be ignored.
+#' @examples
+#' \donttest{
 #' # pptx example -------
 #' doc.filename = "ex_paragraph.pptx"
-#' @example examples/pptx.R
-#' @example examples/addSlide.R
-#' @example examples/addTitle1NoLevel.R
-#' @example examples/addParagraph_hello_nostylename.R
-#' @example examples/addSlide.R
-#' @example examples/addTitle2NoLevel.R
-#' @example examples/pot1_example.R
-#' @example examples/pot2_example.R
-#' @example examples/set_of_paragraphs_example.R
-#' @example examples/addParagraph_sop_nostylename.R
-#' @example examples/addParagraph_position_parProperties.R
-#' @example examples/addSlide.R
-#' @example examples/addTitle3NoLevel.R
-#' @example examples/pot1_example.R
-#' @example examples/pot2_example.R
-#' @example examples/set_of_paragraphs_example.R
-#' @example examples/addParagraph_parProperties.R
-#' @example examples/addSlide.R
-#' @example examples/addTitle1NoLevel.R
-#' @example examples/lists_slide.R
-#' @example examples/writeDoc_file.R
+#' doc <- pptx()
+#' doc <- addSlide(doc, "Title and Content")
+#' # Add "Hello World" into the document doc
+#' doc <- addParagraph(doc, "Hello Word" )
+#'
+#' doc <- addSlide(doc, "Title and Content")
+#' doc <- addParagraph( doc, value = my.pars )
+#' # Add my.pars into the document doc
+#' doc <- addParagraph(doc, my.pars, offx = 3, offy = 3,
+#'   width = 2, height = 0.5,
+#'   par.properties=parProperties(text.align="center", padding=0) )
+
+#' doc <- addSlide(doc, "Title and Content")
+#' # Add my.pars into the document doc
+#' doc <- addParagraph(doc, my.pars,
+#'   par.properties=parProperties(text.align="center", padding=24) )
+#'
+#' writeDoc( doc, file = doc.filename )
+#' }
 #' @rdname addParagraph
 #' @export
 addParagraph.pptx <- function(doc, value, offx, offy, width, height,
@@ -224,40 +215,46 @@ addParagraph.pptx <- function(doc, value, offx, offy, width, height,
   }
 
 
-  if( inherits( value, "character" ) ){
-    value = gsub("\\r", "", value )
-    x = lapply( value, function(x) pot(value = x) )
-    value = do.call( "set_of_paragraphs", x )
-  }
   if( inherits( value, "pot" ) ){
     value = set_of_paragraphs( value )
   }
-
-  if( !inherits(value, "set_of_paragraphs") )
+  valid_class <- any( c("set_of_paragraphs", "character") %in% class(value) )
+  if( !valid_class )
     stop("value must be an object of class pot, set_of_paragraphs or a character vector.")
 
-  if( !missing(par.properties) && !inherits( par.properties, "parProperties" ) ){
-    stop("argument 'par.properties' must be an object of class 'parProperties'")
-  }
-
   slide = doc$current_slide
-  if( !missing(par.properties) )
-    parset = .jset_of_paragraphs(value, par.properties)
-  else parset = .jset_of_paragraphs(value)
 
-  if( check.dims > 3 ){
-    if( missing(par.properties) )
-      stop("You have to specify par.properties when using arguments offx and offy")
-    out = .jcall( slide, "I", "add", parset
-                  , as.double( offx ), as.double( offy ), as.double( width ), as.double( height ),
-                  as.logical(restart.numbering) )
+  if( is.character( value ) && !append ){
+    out = .jcall( slide, "I", "add" , .jarray(value) )
+  } else if(is.character( value ) && append) {
+    out = .jcall( slide, "I", "append" , .jarray(value) )
   } else {
-    if( append ){
-      out = .jcall( slide, "I", "append" , parset, as.logical(restart.numbering))
-      if( out == 1) stop("append is possible if current shape is a shape containing paragraphs.")
-    } else out = .jcall( slide, "I", "add" , parset, as.logical(restart.numbering))
+    if( !missing(par.properties) && !inherits( par.properties, "parProperties" ) ){
+      stop("argument 'par.properties' must be an object of class 'parProperties'")
+    }
+
+    if( !missing(par.properties) )
+      parset = .jset_of_paragraphs(value, par.properties)
+    else parset = .jset_of_paragraphs(value)
+
+    if( check.dims > 3 ){
+      if( missing(par.properties) )
+        stop("You have to specify par.properties when using arguments offx and offy")
+      out = .jcall( slide, "I", "add", parset
+                    , as.double( offx ), as.double( offy ), as.double( width ), as.double( height ),
+                    as.logical(restart.numbering) )
+    } else {
+      if( append ){
+        out = .jcall( slide, "I", "append" , parset, as.logical(restart.numbering))
+        if( out == 1) stop("append is possible if current shape is a shape containing paragraphs.")
+      } else {
+        out = .jcall( slide, "I", "add" , parset, as.logical(restart.numbering))
+      }
+    }
+
   }
 
+
   if( isSlideError( out ) ){
     stop( getSlideErrorString( out , "pot") )
   }
