@@ -140,7 +140,7 @@ public class NumberingDefinition implements HTML4R, DOCX4R{
 		return list_pointers.containsKey( new Integer( list_id ) );
 	}
 	@Override
-	public Object get_docx_elt() throws Exception {
+	public Object get_flextable_docx() throws Exception {
 		
 
 		
