@@ -9,6 +9,6 @@
 package org.lysis.reporters.tools;
 
 public interface DOCX4R {
-	public Object get_docx_elt() throws Exception;
+	public Object get_flextable_docx() throws Exception;
 
 }
