@@ -9,5 +9,5 @@
 package org.lysis.reporters.tools;
 
 public interface PPTX4R {
-	public Object get_pptx_elt() throws Exception;
+	public Object get_flextable_pptx() throws Exception;
 }
